@@ -4,7 +4,7 @@
 # @Project : chpypi
 # @Software: PyCharm
 
-proxiesKey = "wmzr5n8v"
+proxiesKey = "6ienvavm"
 
 # 代理服务器
 proxyHost = "http-dyn.abuyun.com"
